@@ -1,11 +1,10 @@
-from python_jsonschema_objects import util
-from python_jsonschema_objects import validators
 import functools
-import logging
-import six
 import operator
 
 
+from python_jsonschema_objects import util, validators
+
+
 def MakeLiteral(name, typ, value, **properties):
     properties.update({"type": typ})
     klass = type(
@@ -39,11 +38,12 @@ class LiteralValue(object):
         else:
             self._value = value
 
-        if self._value is None and self.default() is not None:
-            self._value = self.default()
-
         self.validate()
 
+        constval = self.const()
+        if constval is not None:
+            self._value = constval
+
     def as_dict(self):
         return self.for_json()
 
@@ -54,6 +54,10 @@ class LiteralValue(object):
     def default(cls):
         return cls.__propinfo__.get("__default__")
 
+    @classmethod
+    def const(cls):
+        return cls.__propinfo__.get("__literal__", {}).get("const", None)
+
     @classmethod
     def propinfo(cls, propname):
         if propname not in cls.__propinfo__:
@@ -69,16 +73,17 @@ class LiteralValue(object):
         return "<Literal<%s> %s>" % (self._value.__class__.__name__, str(self._value))
 
     def __str__(self):
-        if isinstance(self._value, six.string_types):
+        if isinstance(self._value, str):
             return self._value
         return str(self._value)
 
     def validate(self):
         info = self.propinfo("__literal__")
 
-        # TODO: this duplicates logic in validators.ArrayValidator.check_items; unify it.
+        # TODO: this duplicates logic in validators.ArrayValidator.check_items;
+        # unify it.
         for param, paramval in sorted(
-            six.iteritems(info), key=lambda x: x[0].lower() != "type"
+            info.items(), key=lambda x: x[0].lower() != "type"
         ):
             validator = validators.registry(param)
             if validator is not None:
